@@ -14,7 +14,7 @@ use base qw(Verilog::Netlist::Subclass);
 use strict;
 use vars qw($Debug $Verbose $VERSION);
 
-$VERSION = '3.312';
+$VERSION = '3.315';
 
 ######################################################################
 #### Error Handling
@@ -139,6 +139,15 @@ sub new_module {
     return $modref;
 }
 
+sub new_root_module {
+    my $self = shift;
+    $self->{_modules}{'$root'} ||=
+	$self->new_module(keyword=>'root_module',
+			  name=>'$root',
+			  @_);
+    return $self->{_modules}{'$root'};
+}
+
 sub defvalue_nowarn {
     my $self = shift;
     my $sym = shift;
@@ -581,6 +590,11 @@ be first, the top most module will be last.
 
 Creates a new Verilog::Netlist::Module.
 
+=item $netlist->new_root_module
+
+Creates a new Verilog::Netlist::Module for $root, if one doesn't already
+exist.
+
 =item $netlist->top_modules_sorted
 
 Returns name sorted list of Verilog::Netlist::Module, only for those
@@ -673,7 +687,7 @@ Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
 L<http://www.veripool.org/verilog-perl>.
 
-Copyright 2000-2011 by Wilson Snyder.  This package is free software; you
+Copyright 2000-2012 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
