@@ -1,7 +1,7 @@
 // -*- C++ -*-
 //*************************************************************************
 //
-// Copyright 2000-2010 by Wilson Snyder.  This program is free software;
+// Copyright 2000-2012 by Wilson Snyder.  This program is free software;
 // you can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 //
@@ -80,6 +80,8 @@ class VParseLex {
     int		m_aheadToken;		///< Token we read ahead
     VParseBisonYYSType m_aheadVal;	///< aheadToken's value
 
+    int		m_pvstate;		///< "pure virtual" detection
+
     // Parse state
     YY_BUFFER_STATE  m_yyState;	///< flex input state
 
@@ -92,6 +94,7 @@ class VParseLex {
 	m_parsep = parsep;
 	m_inCellDefine = false;
 	m_ahead = false;
+	m_pvstate = 0;
 
 	m_yyState = yy_create_buffer(NULL, YY_BUF_SIZE);
 	s_currentLexp = this;
@@ -110,10 +113,11 @@ class VParseLex {
 	// Are \ escapes needed to print this symbol?
 	if (leng<1) return false;  // Probably not a valid identifier, but better than a core dump...
 	if (!isalpha(textp[0]) && textp[0] != '_') return false;
-	while (leng) {
-	    if (!isalnum(*textp) && *textp != '_') return false;
-	    leng--; textp++;
+	const char* cp = textp;
+	for (size_t tleng=leng; tleng; tleng--, cp++) {
+	    if (!isalnum(*cp) && *cp != '_') return false;
 	}
+	if (VParse::isKeyword(textp, leng)) return false;
 	return true;
     }
 
